@@ -8,11 +8,12 @@ from easytradesdk.Serializer import DeserializableObject
 
 class Slippage(DeserializableObject):
 
-    def __init__(self, slippageType=1, value=decimal.Decimal('0')):
+    def __init__(self, slippageType=1, value=0):
+
         # 滑点类型 1:百分比  2:某个具体的值
         self.slippageType = slippageType
 
-        self.value = value
+        self.value = decimal.Decimal(str(value))
 
     def getObjectMapper(self):
         return {"value": decimal.Decimal}
